@@ -24,21 +24,31 @@ initTestData() {
     #-- fill test data arrays
     
     # Number of component, action and viewer extensions
-    componentExtensionCount=( [5.1]=14  [5.0]=14  [4.1]=14  [4.0]=14  )
-    actionExtensionCount=(    [5.1]=33  [5.0]=33  [4.1]=27  [4.0]=27  )
-    viewerExtensionCount=(    [5.1]=10  [5.0]=10                      )
+    componentExtensionCount=( [5.3]=15 [5.2]=15  [5.1]=14  [5.0]=14  [4.1]=14  [4.0]=14   )
+    actionExtensionCount=(    [5.3]=34 [5.2]=34  [5.1]=33  [5.0]=33  [4.1]=27  [4.0]=27   )
+    viewerExtensionCount=(    [5.3]=10 [5.2]=10  [5.1]=10  [5.0]=10                       )
     
     # Number of different file format/extension manages by the component extensions
-    fileExtensionCount=(      [5.1]=37  [5.0]=37  [4.1]=37  [4.0]=37  )
+    fileExtensionCount=(      [5.3]=38 [5.2]=38  [5.1]=37  [5.0]=37  [4.1]=37  [4.0]=37   )
     
     # Number of actions provided by the action extensions
-    actionCount=(             [5.1]=111 [5.0]=111 [4.1]=105 [4.0]=105 )
+    actionCount=(             [5.3]=115 [5.2]=115 [5.1]=111 [5.0]=111 [4.1]=105 [4.0]=105 )
     
     # Number of viewers managed by the viewer extensions
-    viewerCount=(             [5.1]=13  [5.0]=13                      )
+    viewerCount=(             [5.3]=13 [5.2]=13  [5.1]=13  [5.0]=13                       )
+
+    #-- extensionCount is just the sum of all three extension counts
+    extensionCount=(          [5.3]=$((componentExtensionCount[5.3] + actionExtensionCount[5.3] + viewerExtensionCount[5.3]))
+                              [5.2]=$((componentExtensionCount[5.2] + actionExtensionCount[5.2] + viewerExtensionCount[5.2]))
+                              [5.1]=$((componentExtensionCount[5.1] + actionExtensionCount[5.1] + viewerExtensionCount[5.1]))
+                              [5.0]=$((componentExtensionCount[5.0] + actionExtensionCount[5.0] + viewerExtensionCount[5.0]))
+                              [4.1]=$((componentExtensionCount[4.1] + actionExtensionCount[4.1])) 
+                              [4.0]=$((componentExtensionCount[4.0] + actionExtensionCount[4.0]))  )
 
     #-- Release date
-    releaseDate=(             [5.1]="not yet released, current development version" \
+    releaseDate=(             [5.3]="not yet released, current development version" \
+                              [5.2]="15 February 2024" \
+                              [5.1]="28 July 2023" \
                               [5.0]="30 April 2021" \
                               [4.1]="15 July 2018" \
                               [4.0]="22 July 2016" \
@@ -49,12 +59,6 @@ initTestData() {
                               [3.1]="1 March 2013" \
                               [3.0]="7 July 2012" )
 
-    #-- extensionCount is just the sum of all three extension counts
-    extensionCount=(          [5.1]=$((componentExtensionCount[5.1] + actionExtensionCount[5.1] + viewerExtensionCount[5.1]))
-                              [5.0]=$((componentExtensionCount[5.0] + actionExtensionCount[5.0] + viewerExtensionCount[5.0]))
-                              [4.1]=$((componentExtensionCount[4.1] + actionExtensionCount[4.1])) 
-                              [4.0]=$((componentExtensionCount[4.0] + actionExtensionCount[4.0]))  )
-
 }
 
 # ---------------------- declareTestData ----------------------
@@ -273,7 +277,7 @@ trap "cleanup" 0 INT QUIT ABRT PIPE TERM EXIT
 
 # add java to LD_LIBRARY_PATH to fix strange dependency (is it due to VTK9 package?)
 export JAVA_HOME=/usr/lib/jvm/default-java
-export LD_LIBRARY_PATH=${JAVA_HOME}/lib/:${JAVA_HOME}/lib/server/
+export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${JAVA_HOME}/lib/:${JAVA_HOME}/lib/server/
 
 declareTestData
 initTestData
